@@ -8,4 +8,13 @@ pub struct Function {
 
 	/// The argument type definitions of the function.
 	pub args: RefCell<Vec<ValueType>>
+}
+
+impl Function {
+	pub fn new() -> Function {
+		Function {
+			ret: ValueType::Void,
+			args: RefCell::new(Vec::new())
+		}
+	}
 }
\ No newline at end of file
